@@ -27,6 +27,8 @@
 #include "outbound.h"
 #include "cfgfiles.h"
 #include "ignore.h"
+#include "server.h"
+#include "servlist.h"
 #include "modes.h"
 #include "notify.h"
 #include "text.h"
@@ -263,10 +265,10 @@ plugin_add (session *sess, char *filename, void *handle, void *init_func,
 		pl->xchat_list_time = xchat_list_time;
 		pl->xchat_gettext = xchat_gettext;
 		pl->xchat_send_modes = xchat_send_modes;
+		pl->xchat_strip = xchat_strip;
+		pl->xchat_free = xchat_free;
 
 		/* incase new plugins are loaded on older xchat */
-		pl->xchat_dummy6 = xchat_dummy;
-		pl->xchat_dummy5 = xchat_dummy;
 		pl->xchat_dummy4 = xchat_dummy;
 		pl->xchat_dummy3 = xchat_dummy;
 		pl->xchat_dummy2 = xchat_dummy;
@@ -388,12 +390,12 @@ plugin_load (session *sess, char *filename, char *arg)
 	else
 		handle = dlopen (filename, RTLD_GLOBAL | RTLD_NOW);
 	if (handle == NULL)
-		return dlerror ();
+		return (char *)dlerror ();
 	dlerror ();		/* Clear any existing error */
 
 	/* find the init routine xchat_plugin_init */
 	init_func = dlsym (handle, "xchat_plugin_init");
-	error = dlerror ();
+	error = (char *)dlerror ();
 	if (error != NULL)
 	{
 		dlclose (handle);
@@ -402,7 +404,7 @@ plugin_load (session *sess, char *filename, char *arg)
 
 	/* find the plugin's deinit routine, if any */
 	deinit_func = dlsym (handle, "xchat_plugin_deinit");
-	error = dlerror ();
+	error = (char *)dlerror ();
 #endif
 
 	/* add it to our linked list */
@@ -573,6 +575,34 @@ plugin_emit_dummy_print (session *sess, char *name)
 	return plugin_hook_run (sess, name, word, NULL, HOOK_PRINT);
 }
 
+int
+plugin_emit_keypress (session *sess, unsigned int state, unsigned int keyval,
+							 int len, char *string)
+{
+	char *word[PDIWORDS];
+	char keyval_str[16];
+	char state_str[16];
+	char len_str[16];
+	int i;
+
+	if (!hook_list)
+		return 0;
+
+	sprintf (keyval_str, "%u", keyval);
+	sprintf (state_str, "%u", state);
+	sprintf (len_str, "%d", len);
+
+	word[0] = "Key Press";
+	word[1] = keyval_str;
+	word[2] = state_str;
+	word[3] = string;
+	word[4] = len_str;
+	for (i = 5; i < PDIWORDS; i++)
+		word[i] = "\000";
+
+	return plugin_hook_run (sess, word[0], word, NULL, HOOK_PRINT);
+}
+
 static int
 plugin_timeout_cb (xchat_hook *hook)
 {
@@ -876,7 +906,7 @@ xchat_find_context (xchat_plugin *ph, const char *servname, const char *channel)
 	while (slist)
 	{
 		serv = slist->data;
-		netname = get_network (serv->front_session, TRUE);
+		netname = server_get_network (serv, TRUE);
 
 		if (servname == NULL ||
 			 rfc_casecmp (servname, serv->servername) == 0 ||
@@ -926,18 +956,38 @@ xchat_get_info (xchat_plugin *ph, const char *id)
   	case 0x2c0b7d03: /* channel */
 		return sess->channel;
 
+	case 0x2c0d614c: /* charset */
+		{
+			const char *locale;
+
+			if (sess->server->encoding)
+				return sess->server->encoding;
+
+			locale = NULL;
+			g_get_charset (&locale);
+			return locale;
+		}
+
 	case 0x30f5a8: /* host */
 		return sess->server->hostname;
 
+	case 0x1c0e99c1: /* inputbox */
+		return fe_get_inputbox_contents (sess);
+
 	case 0x325acab5:	/* libdirfs */
 		return XCHATLIBDIR;
 
 	case 0x6de15a2e:	/* network */
-		return get_network (sess, FALSE);
+		return server_get_network (sess->server, FALSE);
 
 	case 0x339763: /* nick */
 		return sess->server->nick;
 
+	case 0x438fdf9: /* nickserv */
+		if (sess->server->network)
+			return ((ircnet *)sess->server->network)->nickserv;
+		return NULL;
+
 	case 0xca022f43: /* server */
 		if (!sess->server->connected)
 			return NULL;
@@ -973,6 +1023,13 @@ xchat_get_prefs (xchat_plugin *ph, const char *name, const char **string, int *i
 {
 	int i = 0;
 
+	/* some special run-time info (not really prefs, but may aswell throw it in here) */
+	if (!strcmp (name, "state_cursor"))
+	{
+		*integer = fe_get_inputbox_cursor (ph->context);
+		return 2;
+	}
+
 	do
 	{
 		if (!strcasecmp (name, vars[i].name))
@@ -1080,33 +1137,33 @@ xchat_list_next (xchat_plugin *ph, xchat_list *xlist)
 	return 1;
 }
 
-const char **
+const char * const *
 xchat_list_fields (xchat_plugin *ph, const char *name)
 {
-	static const char *dcc_fields[] =
+	static const char * const dcc_fields[] =
 	{
 		"iaddress32","icps",		"sdestfile","sfile",		"snick",	"iport",
 		"ipos",		"iresume",	"isize",		"istatus", 	"itype",		NULL
 	};
-	static const char *channels_fields[] =
+	static const char * const channels_fields[] =
 	{
 		"schannel",	"schantypes", "pcontext", "iflags", "iid", "imaxmodes",
 		"snetwork", "snickmodes", "snickprefixes", "sserver", "itype", "iusers",
 		NULL
 	};
-	static const char *ignore_fields[] =
+	static const char * const ignore_fields[] =
 	{
 		"iflags", "smask", NULL
 	};
-	static const char *notify_fields[] =
+	static const char * const notify_fields[] =
 	{
 		"iflags", "snick", "toff", "ton", "tseen", NULL
 	};
-	static const char *users_fields[] =
+	static const char * const users_fields[] =
 	{
-		"iaway", "shost", "snick", "sprefix", NULL
+		"iaway", "shost", "tlasttalk", "snick", "sprefix", NULL
 	};
-	static const char *list_of_lists[] =
+	static const char * const list_of_lists[] =
 	{
 		"channels",	"dcc", "ignore", "notify", "users", NULL
 	};
@@ -1134,7 +1191,7 @@ time_t
 xchat_list_time (xchat_plugin *ph, xchat_list *xlist, const char *name)
 {
 	guint32 hash = str_hash (name);
-/*	gpointer data = xlist->pos->data;*/
+	gpointer data;
 
 	switch (xlist->type)
 	{
@@ -1150,6 +1207,15 @@ xchat_list_time (xchat_plugin *ph, xchat_list *xlist, const char *name)
 		case 0x35ce7b:	/* seen */
 			return xlist->notifyps->lastseen;
 		}
+		break;
+
+	case LIST_USERS:
+		data = xlist->pos->data;
+		switch (hash)
+		{
+		case 0xa9118c42:	/* lasttalk */
+			return ((struct User *)data)->lasttalk;
+		}
 	}
 
 	return (time_t) -1;
@@ -1173,7 +1239,7 @@ xchat_list_str (xchat_plugin *ph, xchat_list *xlist, const char *name)
 		case 0x38b735af: /* context */
 			return data;	/* this is a session * */
 		case 0x6de15a2e: /* network */
-			return get_network ((session *)data, FALSE);
+			return server_get_network (((session *)data)->server, FALSE);
 		case 0x8455e723: /* nickprefixes */
 			return ((session *)data)->server->nick_prefixes;
 		case 0x829689ad: /* nickmodes */
@@ -1376,3 +1442,15 @@ xchat_send_modes (xchat_plugin *ph, const char **targets, int ntargets, int mode
 
 	send_channel_modes (ph->context, tbuf, (char **)targets, 0, ntargets, sign, mode, modes_per_line);
 }
+
+char *
+xchat_strip (xchat_plugin *ph, const char *str, int len, int flags)
+{
+	return strip_color ((char *)str, len, (flags & 1), (flags & 2));
+}
+
+void
+xchat_free (xchat_plugin *ph, void *ptr)
+{
+	free (ptr);
+}
